@@ -20,16 +20,13 @@ import time
 import json
 import os
 from nltk import flatten
-
-DIR = os.path.dirname(__file__)
+import bearing_config.json as bearing_configr
+"""DIR = os.path.dirname(__file__)
 if not DIR:
     FILE_PATH = "bearing_config.json"
 else:
-    FILE_PATH = DIR + "/bearing_config.json"
-
-bearing_config = None
-with open(FILE_PATH, 'r') as readfile:
-    bearing_config = json.load(readfile)
+    FILE_PATH = DIR + "/bearing_config.json"""
+bearing_config = json.load(bearing_configr)
 
 
 class Bear(object):
